@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2003-2007 Imendio AB
  * Copyright (C) 2007-2011 Collabora Ltd.
+ * Copyright (C) 2012 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -37,12 +38,14 @@
 #include <telepathy-logger/event.h>
 #include <telepathy-logger/event-internal.h>
 #include <telepathy-logger/log-store-internal.h>
+#include <telepathy-logger/log-store-empathy-internal.h>
 #include <telepathy-logger/log-store-xml-internal.h>
 #include <telepathy-logger/log-store-pidgin-internal.h>
 #include <telepathy-logger/log-store-sqlite-internal.h>
 
 #define DEBUG_FLAG TPL_DEBUG_LOG_MANAGER
 #include <telepathy-logger/debug-internal.h>
+#include <telepathy-logger/log-walker-internal.h>
 #include <telepathy-logger/util-internal.h>
 
 /**
@@ -116,6 +119,7 @@ typedef struct
 
 
 G_DEFINE_TYPE (TplLogManager, tpl_log_manager, G_TYPE_OBJECT);
+
 G_DEFINE_BOXED_TYPE (TplLogSearchHit,
     _tpl_log_manager_search_hit,
     _tpl_log_manager_search_hit_copy,
@@ -183,22 +187,11 @@ tpl_log_manager_class_init (TplLogManagerClass *klass)
 }
 
 
-static TplLogStore *
+static void
 add_log_store (TplLogManager *self,
-    GType type,
-    const char *name,
-    gboolean readable,
-    gboolean writable)
+    TplLogStore *store)
 {
-  TplLogStore *store;
-
-  g_return_val_if_fail (g_type_is_a (type, TPL_TYPE_LOG_STORE), NULL);
-
-  store = g_object_new (type,
-      "name", name,
-      "readable", readable,
-      "writable", writable,
-      NULL);
+  g_return_if_fail (TPL_IS_LOG_STORE (store));
 
   /* set the log store in "testmode" if it supports it and the environment is
    * currently in test mode */
@@ -207,16 +200,12 @@ add_log_store (TplLogManager *self,
           "testmode", (g_getenv ("TPL_TEST_MODE") != NULL),
           NULL);
 
-  if (store == NULL)
-    CRITICAL ("Error creating %s (name=%s)", g_type_name (type), name);
-  else if (!_tpl_log_manager_register_log_store (self, store))
-    CRITICAL ("Failed to register store name=%s", name);
+  if (!_tpl_log_manager_register_log_store (self, store))
+    CRITICAL ("Failed to register store name=%s",
+        _tpl_log_store_get_name (store));
 
-  if (store != NULL)
-    /* drop the initial ref */
-    g_object_unref (store);
-
-  return store;
+  /* drop the initial ref */
+  g_object_unref (store);
 }
 
 
@@ -273,7 +262,6 @@ _list_of_date_free (gpointer data)
 static void
 tpl_log_manager_init (TplLogManager *self)
 {
-  TplLogStore *store;
   TplLogManagerPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
       TPL_TYPE_LOG_MANAGER, TplLogManagerPriv);
 
@@ -287,17 +275,23 @@ tpl_log_manager_init (TplLogManager *self)
       G_CALLBACK (_globally_enabled_changed), NULL);
 
   /* The TPL's default read-write logstore */
-  add_log_store (self, TPL_TYPE_LOG_STORE_XML, "TpLogger", TRUE, TRUE);
+  add_log_store (self,
+      g_object_new (TPL_TYPE_LOG_STORE_XML,
+          NULL));
 
   /* Load by default the Empathy's legacy 'past coversations' LogStore */
-  store = add_log_store (self, TPL_TYPE_LOG_STORE_XML, "Empathy", TRUE, FALSE);
-  if (store != NULL)
-    g_object_set (store, "empathy-legacy", TRUE, NULL);
+  add_log_store (self,
+      g_object_new (TPL_TYPE_LOG_STORE_EMPATHY,
+          NULL));
 
-  add_log_store (self, TPL_TYPE_LOG_STORE_PIDGIN, "Pidgin", TRUE, FALSE);
+  add_log_store (self,
+      g_object_new (TPL_TYPE_LOG_STORE_PIDGIN,
+          NULL));
 
   /* Load the event counting cache */
-  add_log_store (self, TPL_TYPE_LOG_STORE_SQLITE, "Sqlite", FALSE, TRUE);
+  add_log_store (self,
+      g_object_new (TPL_TYPE_LOG_STORE_SQLITE,
+          NULL));
 
   DEBUG ("Log Manager initialised");
 }
@@ -321,13 +315,8 @@ tpl_log_manager_dup_singleton (void)
  * @event: a TplEvent subclass's instance
  * @error: the memory location of GError, filled if an error occurs
  *
- * It stores @event, sending it to all the registered TplLogStore which have
- * #TplLogStore:writable set to %TRUE.
- * Every TplLogManager is guaranteed to have at least a readable
- * and a writable TplLogStore regitered.
- *
- * It applies for any registered TplLogStore with #TplLogstore:writable property
- * %TRUE
+ * It stores @event, sending it to all the writable registered #TplLogStore objects.
+ * (Every TplLogManager is guaranteed to have at least one writable log store.)
  *
  * Returns: %TRUE if the event has been successfully added, otherwise %FALSE.
  */
@@ -391,19 +380,16 @@ _tpl_log_manager_add_event (TplLogManager *manager,
  * It registers @logstore into @manager, the log store has to be an
  * implementation of the TplLogStore interface.
  *
- * @logstore has to properly implement the add_event method if the
- * #TplLogStore:writable is set to %TRUE.
- *
  * @logstore has to properly implement all the search/query methods if the
- * #TplLogStore:readable is set to %TRUE.
+ * TplLogStore:readable is set to %TRUE.
  */
 gboolean
 _tpl_log_manager_register_log_store (TplLogManager *self,
     TplLogStore *logstore)
 {
   TplLogManagerPriv *priv = self->priv;
+  const gchar *name = _tpl_log_store_get_name (logstore);
   GList *l;
-  gboolean found = FALSE;
 
   g_return_val_if_fail (TPL_IS_LOG_MANAGER (self), FALSE);
   g_return_val_if_fail (TPL_IS_LOG_STORE (logstore), FALSE);
@@ -412,19 +398,13 @@ _tpl_log_manager_register_log_store (TplLogManager *self,
   for (l = priv->stores; l != NULL; l = g_list_next (l))
     {
       TplLogStore *store = l->data;
-      const gchar *name = _tpl_log_store_get_name (logstore);
 
       if (!tp_strdiff (name, _tpl_log_store_get_name (store)))
         {
-          found = TRUE;
-          break;
+          DEBUG ("name=%s: already registered", name);
+          return FALSE;
         }
     }
-  if (found)
-    {
-      DEBUG ("name=%s: already registered", _tpl_log_store_get_name (logstore));
-      return FALSE;
-    }
 
   if (_tpl_log_store_is_readable (logstore))
     priv->readable_stores = g_list_prepend (priv->readable_stores, logstore);
@@ -450,7 +430,7 @@ _tpl_log_manager_register_log_store (TplLogManager *self,
  *
  * Checks if logs exist for @target.
  *
- * It applies for any registered TplLogStore with the #TplLogStore:readable
+ * It applies for any registered TplLogStore with the TplLogStore:readable
  * property %TRUE.
 
  * Returns: %TRUE logs exist for @target, otherwise %FALSE
@@ -489,7 +469,7 @@ tpl_log_manager_exists (TplLogManager *manager,
  * Retrieves a list of #GDate corresponding to each day
  * at least an event exist for @target_id.
  *
- * It applies for any registered TplLogStore with the #TplLogStore:readable
+ * It applies for any registered TplLogStore with the TplLogStore:readable
  * property %TRUE.
  *
  * Returns: a GList of (GDate *), to be freed using something like
@@ -889,7 +869,7 @@ _get_dates_async_thread (GSimpleAsyncResult *simple,
  * Retrieves a list of #GDate corresponding to each day where
  * at least one event exist for @target.
  *
- * It applies for any registered TplLogStore with the #TplLogStore:readable
+ * It applies for any registered TplLogStore with the TplLogStore:readable
  * property %TRUE.
  */
 void
@@ -1193,6 +1173,51 @@ tpl_log_manager_get_filtered_events_finish (TplLogManager *self,
 }
 
 
+/**
+ * tpl_log_manager_walk_filtered_events:
+ * @manager: a #TplLogManager
+ * @account: a #TpAccount
+ * @target: a non-NULL #TplEntity
+ * @type_mask: event type filter see #TplEventTypeMask
+ * @filter: (scope call) (allow-none): an optional filter function
+ * @filter_data: user data to pass to @filter
+ *
+ * Create a #TplLogWalker to traverse all the events exchanged with @target.
+
+ * Returns: (transfer full): a #TplLogWalker
+ */
+TplLogWalker *
+tpl_log_manager_walk_filtered_events (TplLogManager *manager,
+    TpAccount *account,
+    TplEntity *target,
+    gint type_mask,
+    TplLogEventFilter filter,
+    gpointer filter_data)
+{
+  TplLogManagerPriv *priv;
+  TplLogWalker *walker;
+  GList *l;
+
+  g_return_val_if_fail (TPL_IS_LOG_MANAGER (manager), NULL);
+  g_return_val_if_fail (TPL_IS_ENTITY (target), NULL);
+
+  priv = manager->priv;
+  walker = tpl_log_walker_new (filter, filter_data);
+
+  for (l = priv->readable_stores; l != NULL; l = g_list_next (l))
+    {
+      TplLogStore *store = TPL_LOG_STORE (l->data);
+      TplLogIter *iter;
+
+      iter = _tpl_log_store_create_iter (store, account, target, type_mask);
+      if (iter != NULL)
+        tpl_log_walker_add_iter (walker, iter);
+    }
+
+  return walker;
+}
+
+
 static void
 _get_entities_async_thread (GSimpleAsyncResult *simple,
     GObject *object,
