@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2007 Imendio AB
- * Copyright (C) 2007-2011 Collabora Ltd.
+ * Copyright (C) 2007-2013 Collabora Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -42,6 +42,7 @@
 #include "telepathy-logger/event-internal.h"
 #include "telepathy-logger/text-event.h"
 #include "telepathy-logger/text-event-internal.h"
+#include "telepathy-logger/log-iter-xml-internal.h"
 #include "telepathy-logger/log-manager.h"
 #include "telepathy-logger/log-store-internal.h"
 #include "telepathy-logger/log-manager-internal.h"
@@ -78,21 +79,14 @@
 struct _TplLogStoreXmlPriv
 {
   gchar *basedir;
-  gchar *name;
-  gboolean readable;
-  gboolean writable;
-  gboolean empathy_legacy;
   gboolean test_mode;
   TpAccountManager *account_manager;
 };
 
 enum {
     PROP_0,
-    PROP_NAME,
     PROP_READABLE,
-    PROP_WRITABLE,
     PROP_BASEDIR,
-    PROP_EMPATHY_LEGACY,
     PROP_TESTMODE
 };
 
@@ -101,13 +95,9 @@ static void tpl_log_store_xml_get_property (GObject *object, guint param_id, GVa
     GParamSpec *pspec);
 static void tpl_log_store_xml_set_property (GObject *object, guint param_id, const GValue *value,
     GParamSpec *pspec);
-static const gchar *log_store_xml_get_name (TplLogStore *store);
-static void log_store_xml_set_name (TplLogStoreXml *self, const gchar *data);
 static const gchar *log_store_xml_get_basedir (TplLogStoreXml *self);
 static void log_store_xml_set_basedir (TplLogStoreXml *self,
     const gchar *data);
-static void log_store_xml_set_writable (TplLogStoreXml *self, gboolean data);
-static void log_store_xml_set_readable (TplLogStoreXml *self, gboolean data);
 
 
 G_DEFINE_TYPE_WITH_CODE (TplLogStoreXml, _tpl_log_store_xml,
@@ -148,11 +138,6 @@ log_store_xml_finalize (GObject *object)
       g_free (priv->basedir);
       priv->basedir = NULL;
     }
-  if (priv->name != NULL)
-    {
-      g_free (priv->name);
-      priv->name = NULL;
-    }
 }
 
 
@@ -166,21 +151,12 @@ tpl_log_store_xml_get_property (GObject *object,
 
   switch (param_id)
     {
-      case PROP_NAME:
-        g_value_set_string (value, priv->name);
-        break;
-      case PROP_WRITABLE:
-        g_value_set_boolean (value, priv->writable);
-        break;
       case PROP_READABLE:
-        g_value_set_boolean (value, priv->readable);
+        g_value_set_boolean (value, TRUE);
         break;
       case PROP_BASEDIR:
         g_value_set_string (value, priv->basedir);
         break;
-      case PROP_EMPATHY_LEGACY:
-        g_value_set_boolean (value, priv->empathy_legacy);
-        break;
       case PROP_TESTMODE:
         g_value_set_boolean (value, priv->test_mode);
         break;
@@ -201,18 +177,6 @@ tpl_log_store_xml_set_property (GObject *object,
 
   switch (param_id)
     {
-      case PROP_NAME:
-        log_store_xml_set_name (self, g_value_get_string (value));
-        break;
-      case PROP_READABLE:
-        log_store_xml_set_readable (self, g_value_get_boolean (value));
-        break;
-      case PROP_WRITABLE:
-        log_store_xml_set_writable (self, g_value_get_boolean (value));
-        break;
-      case PROP_EMPATHY_LEGACY:
-        self->priv->empathy_legacy = g_value_get_boolean (value);
-        break;
       case PROP_BASEDIR:
         log_store_xml_set_basedir (self, g_value_get_string (value));
         break;
@@ -237,9 +201,7 @@ _tpl_log_store_xml_class_init (TplLogStoreXmlClass *klass)
   object_class->get_property = tpl_log_store_xml_get_property;
   object_class->set_property = tpl_log_store_xml_set_property;
 
-  g_object_class_override_property (object_class, PROP_NAME, "name");
   g_object_class_override_property (object_class, PROP_READABLE, "readable");
-  g_object_class_override_property (object_class, PROP_WRITABLE, "writable");
 
   /**
    * TplLogStoreXml:basedir:
@@ -253,20 +215,6 @@ _tpl_log_store_xml_class_init (TplLogStoreXmlClass *klass)
       G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_BASEDIR, param_spec);
 
-  /**
-   * TplLogStoreXml:empathy-legacy:
-   *
-   * If %TRUE, the logstore pointed by TplLogStoreXml::base-dir will be
-   * considered formatted as an Empathy's LogStore (pre telepathy-logger).
-   * Xml: %FALSE.
-   */
-  param_spec = g_param_spec_boolean ("empathy-legacy",
-      "EmpathyLegacy",
-      "Enables compatibility with old Empathy's logs",
-      FALSE, G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
-  g_object_class_install_property (object_class, PROP_EMPATHY_LEGACY,
-      param_spec);
-
   param_spec = g_param_spec_boolean ("testmode",
       "TestMode",
       "Whether the logstore is in testmode, for testsuite use only",
@@ -733,7 +681,7 @@ log_store_xml_add_event (TplLogStore *store,
     return add_call_event (self, TPL_CALL_EVENT (event), error);
 
   DEBUG ("TplEntry not handled by this LogStore (%s). "
-      "Ignoring Event", log_store_xml_get_name (store));
+      "Ignoring Event", _tpl_log_store_get_name (store));
   /* do not consider it an error, this LogStore simply do not want/need
    * this Event */
   return TRUE;
@@ -1775,7 +1723,7 @@ log_store_xml_get_name (TplLogStore *store)
 
   g_return_val_if_fail (TPL_IS_LOG_STORE_XML (self), NULL);
 
-  return self->priv->name;
+  return "TpLogger";
 }
 
 
@@ -1796,14 +1744,13 @@ log_store_xml_get_basedir (TplLogStoreXml *self)
       if (self->priv->test_mode && g_getenv ("TPL_TEST_LOG_DIR") != NULL)
         {
           user_data_dir = g_getenv ("TPL_TEST_LOG_DIR");
-          name = self->priv->empathy_legacy ? "Empathy" : "TpLogger";
         }
       else
         {
           user_data_dir = g_get_user_data_dir ();
-          name =  log_store_xml_get_name ((TplLogStore *) self);
         }
 
+      name = _tpl_log_store_get_name ((TplLogStore *) self);
       dir = g_build_path (G_DIR_SEPARATOR_S, user_data_dir, name, "logs",
           NULL);
       log_store_xml_set_basedir (self, dir);
@@ -1814,17 +1761,6 @@ log_store_xml_get_basedir (TplLogStoreXml *self)
 }
 
 
-static void
-log_store_xml_set_name (TplLogStoreXml *self,
-    const gchar *data)
-{
-  g_return_if_fail (TPL_IS_LOG_STORE_XML (self));
-  g_return_if_fail (!TPL_STR_EMPTY (data));
-  g_return_if_fail (self->priv->name == NULL);
-
-  self->priv->name = g_strdup (data);
-}
-
 static void
 log_store_xml_set_basedir (TplLogStoreXml *self,
     const gchar *data)
@@ -1842,26 +1778,6 @@ log_store_xml_set_basedir (TplLogStoreXml *self,
 }
 
 
-static void
-log_store_xml_set_readable (TplLogStoreXml *self,
-    gboolean data)
-{
-  g_return_if_fail (TPL_IS_LOG_STORE_XML (self));
-
-  self->priv->readable = data;
-}
-
-
-static void
-log_store_xml_set_writable (TplLogStoreXml *self,
-    gboolean data)
-{
-  g_return_if_fail (TPL_IS_LOG_STORE_XML (self));
-
-  self->priv->writable = data;
-}
-
-
 static GList *
 log_store_xml_get_filtered_events (TplLogStore *store,
     TpAccount *account,
@@ -1974,6 +1890,20 @@ log_store_xml_clear_entity (TplLogStore *store,
 }
 
 
+static TplLogIter *
+log_store_xml_create_iter (TplLogStore *store,
+    TpAccount *account,
+    TplEntity *target,
+    gint type_mask)
+{
+  g_return_val_if_fail (TPL_IS_LOG_STORE_XML (store), NULL);
+  g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
+  g_return_val_if_fail (TPL_IS_ENTITY (target), NULL);
+
+  return tpl_log_iter_xml_new (store, account, target, type_mask);
+}
+
+
 static void
 log_store_iface_init (gpointer g_iface,
     gpointer iface_data)
@@ -1991,4 +1921,5 @@ log_store_iface_init (gpointer g_iface,
   iface->clear = log_store_xml_clear;
   iface->clear_account = log_store_xml_clear_account;
   iface->clear_entity = log_store_xml_clear_entity;
+  iface->create_iter = log_store_xml_create_iter;
 }
