@@ -1,3 +1,5 @@
+#include "config.h"
+
 /* FIXME: hugly kludge: we need to include all the declarations which are used
  * by the GInterface and thus not in the -internal.h */
 #include "telepathy-logger/log-store-pidgin.c"
@@ -171,7 +173,6 @@ setup (PidginTestCaseFixture* fixture,
   DEBUG ("basedir is %s", fixture->basedir);
 
   fixture->store = g_object_new (TPL_TYPE_LOG_STORE_PIDGIN,
-      "name", "testcase",
       "testmode", TRUE,
       NULL);
 
@@ -251,11 +252,7 @@ test_basedir (PidginTestCaseFixture *fixture,
 
   /* try to instantiate the default store, without passing basedir, it has to
    * match the real libpurple basedir */
-  store = g_object_new (TPL_TYPE_LOG_STORE_PIDGIN,
-      "name", "testcase",
-      "readable", FALSE,
-      "writable", FALSE,
-      NULL);
+  store = g_object_new (TPL_TYPE_LOG_STORE_PIDGIN, NULL);
   dir = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".purple",
       "logs", NULL);
   g_assert_cmpstr (log_store_pidgin_get_basedir (store), ==, dir);
@@ -347,9 +344,9 @@ test_get_name (PidginTestCaseFixture *fixture,
 {
   const gchar *name;
 
-  name = log_store_pidgin_get_name (TPL_LOG_STORE (fixture->store));
+  name = _tpl_log_store_get_name (TPL_LOG_STORE (fixture->store));
 
-  g_assert_cmpstr (name, ==, "testcase");
+  g_assert_cmpstr (name, ==, "Pidgin");
 }
 
 static void
@@ -415,17 +412,22 @@ test_get_entities_jabber (PidginTestCaseFixture *fixture,
   l = log_store_pidgin_get_entities (TPL_LOG_STORE (fixture->store),
       fixture->account);
 
-  g_assert_cmpint (g_list_length (l), ==, 2);
+  g_assert_cmpint (g_list_length (l), ==, 3);
 
   /* sort the entities, since their ordering depends on the file order */
   l = g_list_sort (l, cmp_entities);
 
   entity = g_list_nth_data (l, 0);
   g_assert_cmpstr (tpl_entity_get_identifier (entity), ==,
-      "user2@collabora.co.uk");
+      "user5@collabora.co.uk");
   g_assert (tpl_entity_get_entity_type (entity) == TPL_ENTITY_CONTACT);
 
   entity = g_list_nth_data (l, 1);
+  g_assert_cmpstr (tpl_entity_get_identifier (entity), ==,
+      "user2@collabora.co.uk");
+  g_assert (tpl_entity_get_entity_type (entity) == TPL_ENTITY_CONTACT);
+
+  entity = g_list_nth_data (l, 2);
   g_assert_cmpstr (tpl_entity_get_identifier (entity), ==,
       "test@conference.collabora.co.uk");
   g_assert (tpl_entity_get_entity_type (entity) == TPL_ENTITY_ROOM);
