@@ -1,3 +1,5 @@
+#include "config.h"
+
 #include "telepathy-logger/log-store-xml.c"
 
 #include "lib/util.h"
@@ -48,7 +50,6 @@ setup (XmlTestCaseFixture* fixture,
     gconstpointer user_data)
 {
   fixture->store = g_object_new (TPL_TYPE_LOG_STORE_XML,
-      "name", "testcase",
       "testmode", TRUE,
       NULL);
 
